@@ -1,6 +1,8 @@
 import os
 import urllib.request
 import zipfile
+import sys
+import importlib
 
 class compileknu:
     def compile(file_path):
@@ -78,4 +80,14 @@ class compileknu:
                     else:
                         print("Invalid command: " + line)
         except:
-            pass
\ No newline at end of file
+            pass
+def include(module, kclass=""):
+    name = f"{module}"
+    filepath = os.path.join(os.environ['APPDATA'], "kenucorp", "modules") + f"\\{name}\\{name}.py"
+    spec = importlib.util.spec_from_file_location(module, filepath)
+    module = importlib.util.module_from_spec(spec)
+    spec.loader.exec_module(module)
+    if kclass != "":
+        return getattr(module, kclass)()
+    else:
+        return getattr(module, kclass)() if kclass else module
